runGSEA: Function to run enrichment analysis in R

Description Usage Arguments

Description

A funtion to perform GSEA or PAGE analysis

Usage

1
runGSEA(inputTab, gmtFile, GSAmethod = "gsea", nPerm = 1000)

Arguments

inputTab

Ranked gene list for enrichment analysis, gene symbols as rownames and column stat contains the statistics for the ranking.

gmtFile

A path to the gene signature file.

GSAmethod

Method for enrichment analysis, currently supports GSEA and PAGE

nPerm

Number of permutations for GSEA analysis


lujunyan1118/seahorseCLL documentation built on May 12, 2019, 6:16 p.m.